2022-04-16 Version: 2.1.4
- Support customized host header in vpc access.

2022-03-22 Version: 2.1.3
- Support the new backend service, EventBridge.

2022-03-17 Version: 2.1.2
- Add api DetachPlugin.

2022-03-03 Version: 2.1.1
- DescribeApisByVpcAccess adds path and method of API in result.

2022-01-24 Version: 2.1.0
- Add apis for creating API by using backend service.

2021-12-31 Version: 2.0.3
- Update response parameter in DescribePlugins.
- Add query parameter vpcId, instanceId, port in DescribeVpcAccesses.

2021-12-08 Version: 2.0.2
- Add parameters in ImportSwagger and DryRun.

2021-11-23 Version: 2.0.0
- Update DescribeApisByApp.

2021-10-26 Version: 1.0.0
- Create SDK after migrating from POP to apm.

